@@ -1,6 +1,6 @@
 package File::Monitor::Lite;
 
-use 5.010000;
+use 5.8.6;
 use strict;
 use warnings;
 use File::Spec;
